aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/include/uapi
diff options
context:
space:
mode:
authorJens Axboe <axboe@kernel.dk>2020-01-28 10:15:23 -0700
committerJens Axboe <axboe@kernel.dk>2020-01-28 17:45:31 -0700
commit75c6a03904e0dd414a4d99a3072075cb5117e5bc (patch)
treee32857a196c48554c0a1b746410286d4e4e130f0 /include/uapi
parentio_uring: allow registering credentials (diff)
downloadwireguard-linux-75c6a03904e0dd414a4d99a3072075cb5117e5bc.tar.xz
wireguard-linux-75c6a03904e0dd414a4d99a3072075cb5117e5bc.zip
io_uring: support using a registered personality for commands
For personalities previously registered via IORING_REGISTER_PERSONALITY, allow any command to select them. This is done through setting sqe->personality to the id returned from registration, and then flagging sqe->flags with IOSQE_PERSONALITY. Reviewed-by: Pavel Begunkov <asml.silence@gmail.com> Signed-off-by: Jens Axboe <axboe@kernel.dk>
Diffstat (limited to 'include/uapi')
-rw-r--r--include/uapi/linux/io_uring.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/include/uapi/linux/io_uring.h b/include/uapi/linux/io_uring.h
index b4ccf31db2d1..98105ff8d3e6 100644
--- a/include/uapi/linux/io_uring.h
+++ b/include/uapi/linux/io_uring.h
@@ -40,7 +40,12 @@ struct io_uring_sqe {
};
__u64 user_data; /* data to be passed back at completion time */
union {
- __u16 buf_index; /* index into fixed buffers, if used */
+ struct {
+ /* index into fixed buffers, if used */
+ __u16 buf_index;
+ /* personality to use, if used */
+ __u16 personality;
+ };
__u64 __pad2[3];
};
};